==> aria2-1.16.0.tar.bz2: aria2-1.16.0/src/IteratableChecksumValidator.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_ITERATABLE_CHECKSUM_VALIDATOR_H
#define D_ITERATABLE_CHECKSUM_VALIDATOR_H

#include "IteratableValidator.h"
#include "SharedHandle.h"

namespace aria2 {

class DownloadContext;
class PieceStorage;
class MessageDigest;

class IteratableChecksumValidator:public IteratableValidator
{
private:
  SharedHandle<DownloadContext> dctx_;

  SharedHandle<PieceStorage> pieceStorage_;

  int64_t currentOffset_;

  SharedHandle<MessageDigest> ctx_;
public:
  IteratableChecksumValidator(const SharedHandle<DownloadContext>& dctx,
                              const SharedHandle<PieceStorage>& pieceStorage);

  virtual ~IteratableChecksumValidator();

  virtual void init();

  virtual void validateChunk();

  virtual bool finished() const;

  virtual int64_t getCurrentOffset() const
  {
    return currentOffset_;
  }

  virtual int64_t getTotalLength() const;
};

} // namespace aria2

#endif // D_ITERATABLE_CHECKSUM_VALIDATOR_H

==> aria2_1.18.8.orig.tar.bz2: aria2-1.18.8/src/IteratableChecksumValidator.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_ITERATABLE_CHECKSUM_VALIDATOR_H
#define D_ITERATABLE_CHECKSUM_VALIDATOR_H

#include "IteratableValidator.h"

#include <memory>

namespace aria2 {

class DownloadContext;
class PieceStorage;
class MessageDigest;

class IteratableChecksumValidator:public IteratableValidator
{
private:
  std::shared_ptr<DownloadContext> dctx_;

  std::shared_ptr<PieceStorage> pieceStorage_;

  int64_t currentOffset_;

  std::unique_ptr<MessageDigest> ctx_;
public:
  IteratableChecksumValidator(const std::shared_ptr<DownloadContext>& dctx,
                              const std::shared_ptr<PieceStorage>& pieceStorage);

  virtual ~IteratableChecksumValidator();

  virtual void init() CXX11_OVERRIDE;

  virtual void validateChunk() CXX11_OVERRIDE;

  virtual bool finished() const CXX11_OVERRIDE;

  virtual int64_t getCurrentOffset() const CXX11_OVERRIDE
  {
    return currentOffset_;
  }

  virtual int64_t getTotalLength() const CXX11_OVERRIDE;
};

} // namespace aria2

#endif // D_ITERATABLE_CHECKSUM_VALIDATOR_H
